@@ -1,12 +1,17 @@
+from os import environ
+from subprocess import run
+
 from pybrary.command import Command, Param, ValidationError
+from pybrary import bash
 
 from setux.core.action import Action
 from setux.core.manage import Manager
 from setux.core.module import Module
+from setux.cli.usage import usage
 from ..cmd.cmd import get_commands
 
 
-usage = '''
+help = '''
 actions [pattern]
     list available actions
 
@@ -66,15 +71,23 @@ def header(txt):
 
 
 class Help(Command):
-    '''Show Help
+    '''Show Help.
     '''
     Params = [
         Obj,
     ]
 
     def run(self):
-        target = self.get('target')
         obj = self.get('help_obj')
+        if not obj:
+            tmp = '/tmp/usage'
+            with open(tmp, 'w') as out:
+                out.write(usage())
+            pager = environ['PAGER']
+            run([pager, tmp])
+            return
+
+        target = self.get('target')
         '''
         if version_info >= (3, 10):
             match obj:
@@ -108,5 +121,5 @@ class Help(Command):
             header(f'{action.__name__}')
             print(action.help())
         else:
-            print(usage)
+            print(help)
 
